@@ -74,10 +74,10 @@ def syncify_async_function(async_func):
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
 
-    if loop is None or not loop.is_running():
-        print("loop is none")
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
+    # if loop is None or not loop.is_running():
+    #     print("loop is none")
+    #     loop = asyncio.new_event_loop()
+    #     asyncio.set_event_loop(loop)
 
     def sync_func(*args, **kwargs):
         if not loop.is_running():
